import { PeerbitProxyClient, PeerbitProxyHost, connection } from "@peerbit/proxy";
export class PostMessageNode extends connection.MessageNode {
    targetOrigin;
    windowHandle;
    static messagePrefixKey = "peerbit-proxy-";
    constructor(targetOrigin = "*", windowHandle = globalThis) {
        super({
            addEventListener: (k, fn) => {
                const messageKey = PostMessageNode.messagePrefixKey + k;
                windowHandle.addEventListener("message", (ev) => {
                    if (ev.data.type === messageKey) {
                        fn(ev.data.message, ev.source
                            ? {
                                id: ev.data.message.from,
                                publishMessage: (msg) => ev.source?.postMessage({
                                    type: PostMessageNode.messagePrefixKey + msg.type,
                                    message: msg
                                }, { targetOrigin: "*" }),
                                parent: ev.source === window.top
                            }
                            : undefined);
                    }
                });
            },
            dispatchEvent: (msg) => {
                const messageKey = PostMessageNode.messagePrefixKey + msg.type;
                (windowHandle.top || windowHandle).postMessage({
                    type: messageKey,
                    message: msg
                }, this.targetOrigin, msg.type === "data" ? [msg.data] : undefined); // TODO transferable
            }
        });
        this.targetOrigin = targetOrigin;
        this.windowHandle = windowHandle;
    }
}
export const createClient = async (targetOrigin = "*") => {
    const client = new PeerbitProxyClient(new PostMessageNode(targetOrigin));
    await client.connect();
    return client;
};
export const createHost = async (node, targetOrigin = "*") => {
    if (!node.services.pubsub.emitSelf) {
        throw new Error("Host client property '.services.pubsub.emitSelf' needs to be true");
    }
    const client = new PeerbitProxyHost(node, new PostMessageNode(targetOrigin));
    client.messages.start();
    await client.init();
    return client;
};
//# sourceMappingURL=index.js.map